netapp_ontap.models.consistency_group_response_records_replication_relationships API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_response_records_replication_relationships`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupResponseRecordsReplicationRelationshipsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupResponseRecordsReplicationRelationships object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `is_protected_by_svm_dr: bool GET`

    Indicates whether or not this consistency group is protected by SVM DR.

  `is_source: bool GET`

    Indicates whether or not this consistency group is the source for replication.

  `links: SelfLink GET`

    The links field of the consistency_group_response_records_replication_relationships.

  `uuid: str GET`

    The unique identifier of the SnapMirror relationship.

    Example: 02c9e252-41be-11e9-81d5-00a0986138f7